@@ -23,8 +23,8 @@
  ***************************************************************************
  */
 
-// Generated: genpromote.cpp Sep  9 2003 17:48:47
-template<class A, class B>
+// Generated: genpromote.cpp Oct 21 2004 10:46:03
+template<typename A, typename B>
 class promote_trait {
 public:
         typedef A   T_promote;
