@@ -6,9 +6,7 @@
 #include <blitz/vector-et.h>
 #include <blitz/vecwhere.h>
 
-#ifdef BZ_NAMESPACES
-using namespace blitz;
-#endif
+BZ_USING_NAMESPACE(blitz)
 
 int main()
 {
